==> enterprisemodules-ora_config-3.21.0.tar.gz: enterprisemodules-ora_config-3.21.0/lib/puppet/type/ora_validation.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'
require 'puppet_x/enterprisemodules/oracle/access'

Puppet::Type.newtype(:ora_validation) do
  include EasyType
  include PuppetX::EnterpriseModules::Oracle::Access

  desc <<-DESC
  This type allows you to validate the contents of your Oracle database. Here is an example on how you can
  use this:

      ora_validation { 'Ensure All Default Passwords Are Changed@CNTNR':
        check                   => "SELECT DISTINCT A.USERNAME FROM DBA_USERS_WITH_DEFPWD A, DBA_USERS B WHERE A.USERNAME = B.USERNAME  AND B.ACCOUNT_STATUS = 'OPEN'",
        expected_number_of_rows => 0,
        fail_message            => 'User %<username>s still has a default password.',
        report_as               => 'command',
        fail_command            => "/bin/send_to_montoring --node ${::fqdn} '%<messages>s'",
      }

  The Puppet statement executes a query on the database and report a warning when more the 0 records are
  found. It uses the returned records of the query to generate a good reading error or warning message.
  DESC

  map_titles_to_attributes([
                             /^((@.*)@(.*))$/, [:name, :check, :sid],
                             /^((.*)@(.*))$/,  [:name, :check, :sid],
                             /^((@.*))$/,      [:name, :check],
                             /^((.*))$/,       [:name, :check]
                           ])

  to_get_raw_resources do
    []
  end

  on_modify do
    report
  end

  def report
    message = "Validation #{name}  failed with messages : \n#{@messages.join("\n")}"
    case report_as
    when /warning|WARNING/
      Puppet.warning message
    when /error|ERROR/
      raise Puppet::Error, message
    when /command|COMMAND/
      # Issue a waning and execute the fail_command
      Puppet.warning message
      final_command = format(fail_command, :messages => @messages.join(';'))
      Puppet.debug Puppet::Util::Execution.execute(
        final_command,
        :failonfail => true,
        :combine => true,
        :override_locale => false
      )
    else
      raise "#{report_as} is not a valid value"
    end
  end

  def refresh
    records = execute_check

    report if records.count != expected_number_of_rows
  end

  def execute_check
    records = execute_query(check)
    records = records.collect do |r|
      r = r.transform_keys(&:downcase).transform_keys(&:to_sym)
      r.transform_values(&:strip)
    end
    @messages = records.collect { |r| format(fail_message, r) }
  end

  def execute_query(query)
    options = { :sid => sid, :parse => true }
    options[:username] = username if username.to_s != 'absent'
    options[:password] = password if password.to_s != 'absent'
    sql query, options
  end

  parameter :name
  property  :check
  parameter :sid
  parameter :refreshonly

  parameter :timeout
  parameter :password
  parameter :username
  parameter :report_as
  parameter :expected_number_of_rows
  parameter :fail_message
  parameter :fail_command
end

==> enterprisemodules-ora_config-3.23.4.tar.gz: enterprisemodules-ora_config-3.23.4/lib/puppet/type/ora_validation.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'
require 'puppet_x/enterprisemodules/oracle/access'

Puppet::Type.newtype(:ora_validation) do
  include EasyType
  include PuppetX::EnterpriseModules::Oracle::Access

  desc <<-DESC
  This type allows you to validate the contents of your Oracle database. Here is an example on how you can
  use this:

      ora_validation { 'Ensure All Default Passwords Are Changed@CNTNR':
        check                   => "SELECT DISTINCT A.USERNAME FROM DBA_USERS_WITH_DEFPWD A, DBA_USERS B WHERE A.USERNAME = B.USERNAME  AND B.ACCOUNT_STATUS = 'OPEN'",
        expected_number_of_rows => 0,
        fail_message            => 'User %<username>s still has a default password.',
        report_as               => 'command',
        fail_command            => "/bin/send_to_montoring --node ${::fqdn} '%<messages>s'",
      }

  The Puppet statement executes a query on the database and report a warning when more the 0 records are
  found. It uses the returned records of the query to generate a good reading error or warning message.
  DESC

  map_titles_to_attributes([
                             /^((@.*)@(.*))$/, [:name, :check, :sid],
                             /^((.*)@(.*))$/,  [:name, :check, :sid],
                             /^((@.*))$/,      [:name, :check],
                             /^((.*))$/,       [:name, :check]
                           ])

  to_get_raw_resources do
    []
  end

  #
  # Register the result(s) of a control in the class. The puppet type validation_report can
  # then pass it to the puppet server or any oher place.
  #
  def self.register_result(qualified_control, result, message)
    return if qualified_control.nil?

    control, target = qualified_control.split(/\[|\]/)
    @results ||= {}
    #
    # SOmetimes insync is called multiple times. To guard aganst double messages, check if the message is already registered.
    #
    return if @results[qualified_control] && @results[qualified_control]['results'].any? { |e| e[:message] == message }

    @results[qualified_control] ||= {}
    @results[qualified_control]['control'] ||= control
    @results[qualified_control]['target'] ||= target
    @results[qualified_control]['results'] ||= []
    @results[qualified_control]['results'] << { :message => message, :result => result }
  end

  class << self
    attr_reader :results
  end

  on_modify do
    provider.report
  end

  def refresh
    records = provider.execute_check

    provider.report if records.count != expected_number_of_rows
  end

  parameter :name
  property  :check
  parameter :sid
  parameter :refreshonly
  parameter :control
  parameter :skip

  parameter :timeout
  parameter :password
  parameter :username
  parameter :report_as
  parameter :expected_number_of_rows
  parameter :fail_message
  parameter :fail_command
end
